{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 9</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="alma+marceau">Alma-Marceau</option>
			<option value="billancourt">Billancourt</option>
			<option value="bonne+nouvelle">Bonne Nouvelle</option>
			<option value="buzenval">Buzenval</option>
			<option value="charonne">Charonne</option>
			<option value="chaussee+d+antin+la+fayette">Chaussee d&#039;Antin La Fayette</option>
			<option value="croix+de+chavaux">Croix de Chavaux</option>
			<option value="exelmans">Exelmans</option>
			<option value="grands+boulevards">Grands Boulevards</option>
			<option value="havre+caumartin">Havre-Caumartin</option>
			<option value="iena">Iena</option>
			<option value="jasmin">Jasmin</option>
			<option value="la+muette">La Muette</option>
			<option value="mairie+de+montreuil">Mairie de Montreuil</option>
			<option value="maraichers">Maraîchers</option>
			<option value="marcel+sembat">Marcel Sembat</option>
			<option value="michel+ange+auteuil">Michel-Ange Auteuil</option>
			<option value="michel+ange+molitor">Michel-Ange Molitor</option>
			<option value="miromesnil">Miromesnil</option>
			<option value="oberkampf">Oberkampf</option>
			<option value="pont+de+sevres">Pont de Sevres</option>
			<option value="porte+de+montreuil">Porte de Montreuil</option>
			<option value="porte+de+saint+cloud">Porte de Saint-Cloud</option>
			<option value="ranelagh">Ranelagh</option>
			<option value="richelieu+drouot">Richelieu-Drouot</option>
			<option value="robespierre">Robespierre</option>
			<option value="rue+de+la+pompe">Rue de la Pompe</option>
			<option value="rue+des+boulets">Rue des Boulets</option>
			<option value="republique">Republique</option>
			<option value="saint+ambroise">Saint-Ambroise</option>
			<option value="saint+augustin">Saint-Augustin</option>
			<option value="saint+philippe+du+roule">Saint-Philippe-du-Roule</option>
			<option value="strasbourg+saint+denis">Strasbourg-Saint-Denis</option>
			<option value="trocadero">Trocadero</option>
			<option value="voltaire">Voltaire</option>
			<option value="franklin+d+roosevelt">Franklin D. Roosevelt</option>
			<option value="nation">Nation</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Mairie de Montreuil</option>
				<option value="R">Pont de Sèvre</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>


	{% endblock %}



