{% extends "layout/login.html" %}
{% block body %}


  <div class="login-page">
  <form class="register-form" method=post action=""> 
  <div class="form">
      <img style="max-width: 100%; height:250px; " src="{{ url_for('static' , filename='images/logo.png') }}">
      <input type="text" id="username" name="username" 
            placeholder="Nom de compte" required>
      <input type="password" id="password" name="password" class="input-xlarge"
            placeholder="Mot de Passe" required>
      <button>Se Connecter</button>
      <p class="message">Pas inscrit ? <a href="{{ url_for('register') }}">Créer un compte</a></p>
    </form>
  </div>
</div>


{% endblock %}