{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 10</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="avenue+emile+zola">Avenue Emile Zola</option>
			<option value="boulogne+jean+jaures">Boulogne Jean Jaures</option>
			<option value="boulogne+pont+de+saint+cloud">Boulogne Pont de Saint-Cloud</option>
			<option value="cardinal+lemoine">Cardinal Lemoine</option>
			<option value="chardon+lagache">Chardon-Lagache</option>
			<option value="charles+michels">Charles Michels</option>
			<option value="cluny+la+sorbonne">Cluny La Sorbonne</option>
			<option value="duroc">Duroc</option>
			<option value="gare+d+austerlitz">Gare d&#039;Austerlitz</option>
			<option value="javel+andre+citroen">Javel Andre Citroën</option>
			<option value="jussieu">Jussieu</option>
			<option value="la+motte+picquet+grenelle">La Motte-Picquet Grenelle</option>
			<option value="mabillon">Mabillon</option>
			<option value="maubert+mutualite">Maubert Mutualite</option>
			<option value="michel+ange+molitor">Michel-Ange Molitor</option>
			<option value="mirabeau">Mirabeau</option>
			<option value="odeon">Odeon</option>
			<option value="sevres+babylone">Sevres-Babylone</option>
			<option value="segur">Segur</option>
			<option value="vaneau">Vaneau</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Gare d'Austerlitz</option>
				<option value="R">Boulogne Pont de Saint-Cloud</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>
{% endblock %}


