<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8"/>
        <link href="{{ url_for('static', filename='css/install.css') }}" rel="stylesheet" type="text/css" />
        <link href="{{ url_for('static', filename='css/materialize.css') }}" rel="stylesheet" type="text/css" />
        <link href="http://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
        <title>Onyx | Installation</title>
    </head>
    <body >   
        <div class="container"> 
            <div class="main">  
                <div class="content">{% block body %}{% endblock %}</div> <!-- Include body -->
            </div>     
        </div>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/2.1.4/jquery.min.js"></script>
    <script type="text/javascript" src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/js/bootstrap.min.js" ></script>
    <script src="{{ url_for('static', filename='js/install.js') }}"></script>

    {% block script %}{% endblock %}
</body>  
</html>