<script src="http://cdnjs.cloudflare.com/ajax/libs/jquery/1.10.1/jquery.min.js"></script>
<script src="http://cdnjs.cloudflare.com/ajax/libs/moment.js/2.0.0/moment.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/materialize/0.97.6/js/materialize.min.js"></script>
<script src="{{ url_for('static', filename='js/pnotify.js') }}"></script>    
<script type="text/javascript" src="includes/themeswitcher/jquery.themeswitcher.min.js"></script>
<script src="https://sciactive.github.io/pnotify/src/pnotify.buttons.js"></script>