<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" />
        {% include 'dependencies/cssLogin.html' %}
        {% include 'dependencies/notif.html' %}
        <title>Onyx</title>
    </head>
    <body>
 

      <div class="container">
            <div class="content">{% block body %}{% endblock %}</div>   
      </div>

        {% include 'dependencies/jsLogin.html' %}
</body>  
</html>