{% extends "layout/default.html" %}
{% block body %} 
<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">RER A</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horRERStations" class="stationField">
     		 <label for="RERServiceStationForm_station">Nom de la station : </label> <select name="rerstation" class="browser-default" id="metroServiceStationForm_station">
     			<option value="Aeroport Ch.De Gaulle 1">Aeroport Ch.De Gaulle 1</option>
				<option value="Aeroport Ch.De Gaulle 2">Aeroport Ch.De Gaulle 2</option>
				<option value="Antony" selected="selected">Antony</option>
				<option value="arcueil+cachan">Arcueil Cachan</option>
				<option value="Aubervilliers">Aubervilliers</option>
				<option value="Aulnay Sous Bois">Aulnay Sous Bois</option>
				<option value="Bagneux">Bagneux</option>
				<option value="Blanc-Mesnil">Blanc-Mesnil</option>
				<option value="Bourg la Reine">Bourg la Reine</option>
				<option value="Bures Sur Yvette">Bures Sur Yvette</option>
				<option value="Chatelet">Chatelet</option>
				<option value="Cite Universitaire">Cite Universitaire</option>
				<option value="Courcelle Sur Yvette">Courcelle Sur Yvette</option>
				<option value="Denfert Rochereau">Denfert Rochereau</option>
				<option value="Drancy">Drancy</option>
				<option value="Fontaine Michalon">Fontaine Michalon</option>
				<option value="Fontenay aux Roses">Fontenay aux Roses</option>
				<option value="Gare du Nord">Gare du Nord</option>
				<option value="Gentilly">Gentilly</option>
				<option value="Gif Sur Yvette">Gif Sur Yvette</option>
				<option value="La Croix de Berny">La Croix de Berny</option>
				<option value="La Hacquiniere">La Hacquiniere</option>
				<option value="La Plaine-Stade de France">La Plaine-Stade de France</option>
				<option value="Laplace">Laplace</option>
				<option value="Le Bourget">Le Bourget</option>
				<option value="Le Guichet">Le Guichet</option>
				<option value="Les Baconnets">Les Baconnets</option>
				<option value="Lozere">Lozere</option>
				<option value="Luxembourg">Luxembourg</option>
				<option value="Massy Palaiseau">Massy Palaiseau</option>
				<option value="Massy Verrieres">Massy Verrieres</option>
				<option value="Mitry-Claye">Mitry-Claye</option>
				<option value="Orsay Ville">Orsay Ville</option>
				<option value="Palaiseau">Palaiseau</option>
				<option value="Palaiseau Villebon">Palaiseau Villebon</option>
				<option value="Parc de Sceaux">Parc de Sceaux</option>
				<option value="Parc des Expositions">Parc des Expositions</option>
				<option value="Port Royal">Port Royal</option>
				<option value="Robinson">Robinson</option>
				<option value="Saint Michel">Saint Michel</option>
				<option value="Saint Remy les Chevreuse">Saint Remy les Chevreuse</option>
				<option value="Sceaux">Sceaux</option>
				<option value="Sevran Beaudottes">Sevran Beaudottes</option>
				<option value="Sevran-Livry">Sevran-Livry</option>
				<option value="Vert-Galant">Vert-Galant</option>
				<option value="Villeparisis Mitry">Villeparisis Mitry</option>
				<option value="Villepinte">Villepinte</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="rer-service-arret-form">
   			 <div id="horRERStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="rerdirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Charles-de-Gaulle. Mitry-Claye.</option>
				<option value="R">Robinson. Saint-Rémy-lès-Chevreuse.</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember">Ajouter au favoris
    </label></br></br>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>
{% endblock %}



