{% extends "layout/default.html" %}
{% block body %}
	<h3>Onyx v1.0</h3>
	<h4>Raspberry Pi</h4>
	<h4>Windows/Linux/Mac</h4>	
	<h4>Changelog :</h4>
	<p>Réveil</p>
	<p>Options</p>
	<p>Gestion du compte utilisateur</p>
	<p>Météo</p>
	<p>Taches</p>
	<p>Calendrier</p>
	<p>Wiki</p>
	<p>Musique</p>
	<p>RATP</p>
	<p>Mail</p>
	<p>VersionMobile</p>
{% endblock %}
