{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 5</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="bobigny+pablo+picasso">Bobigny Pablo Picasso</option>
			<option value="bobigny+pantin+raymond+queneau">Bobigny-Pantin Raymond Queneau</option>
			<option value="breguet+sabin">Breguet-Sabin</option>
			<option value="campo+formio">Campo-Formio</option>
			<option value="eglise+de+pantin">Eglise de Pantin</option>
			<option value="gare+d+austerlitz">Gare d&#039;Austerlitz</option>
			<option value="gare+de+l+est">Gare de l&#039;Est</option>
			<option value="gare+du+nord">Gare du Nord</option>
			<option value="hoche">Hoche</option>
			<option value="jacques+bonsergent">Jacques Bonsergent</option>
			<option value="jaures">Jaures</option>
			<option value="laumiere">Laumiere</option>
			<option value="oberkampf">Oberkampf</option>
			<option value="ourcq">Ourcq</option>
			<option value="place+d+italie">Place d&#039;Italie</option>
			<option value="porte+de+pantin">Porte de Pantin</option>
			<option value="quai+de+la+rapee">Quai de la Rapee</option>
			<option value="richard+lenoir">Richard-Lenoir</option>
			<option value="republique">Republique</option>
			<option value="saint+marcel">Saint-Marcel</option>
			<option value="stalingrad">Stalingrad</option>
			<option value="bastille">Bastille</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Place d'Italie</option>
				<option value="R">Bobigny Pablo Picasso</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>

{% endblock %}


