{% macro get_css(nom_fichiers , extension='css') -%}
    {% for fichier in nom_fichiers %}
        <link href="{{ url_for('static', filename='css/' + fichier + '.' + extension) }}" rel="stylesheet" type="text/css" />
    {% endfor %}
{%- endmacro %}
<link rel="shortcut icon" type="image/x-icon" href="{{ url_for('static', filename='images/favicon.ico') }}" />

{{ get_css([ 'materialize' , 'background' , 'hours' , 'notif' , 'wickedpicker.min' , 'notif-theme.min' ]) }}
<link rel="stylesheet" href="http://cdnjs.cloudflare.com/ajax/libs/fullcalendar/2.7.1/fullcalendar.min.css">
<link href="http://cdnjs.cloudflare.com/ajax/libs/animate.css/3.4.0/animate.min.css" rel="stylesheet" type="text/css" />
<link href="https://sciactive.github.io/pnotify/src/pnotify.brighttheme.css" rel="stylesheet" type="text/css" />
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/pnotify/3.0.0/pnotify.css">
<link rel="stylesheet" href="http://cdnjs.cloudflare.com/ajax/libs/fullcalendar/2.7.1/fullcalendar.print.css " media="print">
<link href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.11.3/themes/smoothness/jquery-ui.css" media="all" rel="stylesheet" type="text/css" />
<link rel="stylesheet" type="text/css" href="http://netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css" rel="stylesheet">
<link rel="stylesheet" href="https://cdn.jsdelivr.net/bootstrap.wysihtml5/0.0.2/bootstrap-wysihtml5-0.0.2.css">
<link href="http://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
<link href="https://sciactive.github.io/pnotify/src/pnotify.buttons.css" rel="stylesheet">
<link rel="stylesheet" type="text/css" href="http://materializecss.com/css/prism.css">
<link rel="stylesheet" type="text/css" href="https://cdnjs.cloudflare.com/ajax/libs/jquery.gridster/0.5.6/jquery.gridster.css">