{% extends "layout/default.html" %}
{% block body %}
	<h1>Calendrier</h1>


	<iframe style="border:0px #FFFFFF none;" frameborder="1" width="100%" height="900px" src="{{ url_for('setCalendar') }}"></iframe>
{% endblock %}
