{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 2</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="alexandre+dumas">Alexandre Dumas</option>
				<option value="anvers">Anvers</option>
				<option value="avron">Avron</option>
				<option value="barbes+rochechouart">Barbes Rochechouart</option>
				<option value="belleville">Belleville</option>
				<option value="blanche">Blanche</option>
				<option value="charles+de+gaulle+etoile">Charles de Gaulle Etoile</option>
				<option value="colonel+fabien">Colonel Fabien</option>
				<option value="courcelles">Courcelles</option>
				<option value="couronnes">Couronnes</option>
				<option value="jaures">Jaures</option>
				<option value="la+chapelle">La Chapelle</option>
				<option value="monceau">Monceau</option>
				<option value="menilmontant">Menilmontant</option>
				<option value="nation">Nation</option>
				<option value="philippe+auguste">Philippe Auguste</option>
				<option value="pigalle">Pigalle</option>
				<option value="place+de+clichy">Place de Clichy</option>
				<option value="porte+dauphine">Porte Dauphine</option>
				<option value="pere+lachaise">Pere Lachaise</option>
				<option value="rome">Rome</option>
				<option value="stalingrad">Stalingrad</option>
				<option value="ternes">Ternes</option>
				<option value="victor+hugo">Victor Hugo</option>
				<option value="villiers">Villiers</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Porte Dauphine</option>
				<option value="R">Nation</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>


{% endblock %}

