{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 7</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
    		<option value="aubervilliers+pantin+quatre+chemins">Aubervilliers Pantin Quatre Chemins</option>
			<option value="cadet">Cadet</option>
			<option value="censier+daubenton">Censier Daubenton</option>
			<option value="chaussee+d+antin+la+fayette">Chaussee d&#039;Antin La Fayette</option>
			<option value="chateau+landon">Chateau-Landon</option>
			<option value="corentin+cariou">Corentin Cariou</option>
			<option value="crimee">Crimee</option>
			<option value="fort+d+aubervilliers">Fort d&#039;Aubervilliers</option>
			<option value="gare+de+l+est">Gare de l&#039;Est</option>
			<option value="jussieu">Jussieu</option>
			<option value="la+courneuve 8 mai 1945">La Courneuve 8 mai 1945</option>
			<option value="le+kremlin+bicetre">Le Kremlin-Bicêtre</option>
			<option value="le+peletier">Le Peletier</option>
			<option value="les+gobelins">Les Gobelins</option>
			<option value="louis+blanc">Louis Blanc</option>
			<option value="mairie+d+ivry">Mairie d&#039;Ivry</option>
			<option value="maison+blanche">Maison Blanche</option>
			<option value="opera">Opera</option>
			<option value="pierre+et+marie+curie">Pierre et Marie Curie</option>
			<option value="place+monge">Place Monge</option>
			<option value="place+d+italie">Place d&#039;Italie</option>
			<option value="poissonniere">Poissonniere</option>
			<option value="pont+marie">Pont Marie</option>
			<option value="pont+neuf">Pont Neuf</option>
			<option value="porte+d+italie">Porte d&#039;Italie</option>
			<option value="porte+d+ivry">Porte d&#039;Ivry</option>
			<option value="porte+de+choisy">Porte de Choisy</option>
			<option value="porte+de+la+villette">Porte de la Villette</option>
			<option value="pyramides">Pyramides</option>
			<option value="riquet">Riquet</option>
			<option value="stalingrad">Stalingrad</option>
			<option value="sully+morland">Sully-Morland</option>
			<option value="tolbiac">Tolbiac</option>
			<option value="villejuif+louis+aragon">Villejuif+Louis Aragon</option>
			<option value="villejuif+leo+lagrange">Villejuif Leo Lagrange</option>
			<option value="villejuif+paul+vaillant+couturier">Villejuif Paul Vaillant-Couturier</option>
			<option value="chatelet">Chatelet</option>
			<option value="palais+royal+musee+du+louvre">Palais Royal Musee du Louvre</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Mairie d'Ivry - Villejuif Louis Aragon</option>
				<option value="R">La Courneuve 8 mai 1945</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>



{% endblock %}
