{% extends "layout/default.html" %}
{% block body %} <br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 6</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="bel+air">Bel-Air</option>
			<option value="bercy">Bercy</option>
			<option value="bir+hakeim">Bir-Hakeim</option>
			<option value="boissiere">Boissiere</option>
			<option value="cambronne">Cambronne</option>
			<option value="chevaleret">Chevaleret</option>
			<option value="corvisart">Corvisart</option>
			<option value="daumesnil">Daumesnil</option>
			<option value="denfert+rochereau">Denfert-Rochereau</option>
			<option value="dugommier">Dugommier</option>
			<option value="dupleix">Dupleix</option>
			<option value="edgar+quinet">Edgar Quinet</option>
			<option value="glaciere">Glaciere</option>
			<option value="kleber">Kleber</option>
			<option value="la+motte+picquet+grenelle">La Motte-Picquet Grenelle</option>
			<option value="montparnasse+bienvenue">Montparnasse Bienvenüe</option>
			<option value="nationale">Nationale</option>
			<option value="passy">Passy</option>
			<option value="pasteur">Pasteur</option>
			<option value="picpus">Picpus</option>
			<option value="place+d+italie">Place d&#039;Italie</option>
			<option value="quai+de+la+gare">Quai de la Gare</option>
			<option value="raspail">Raspail</option>
			<option value="saint+jacques">Saint-Jacques</option>
			<option value="sevres+lecourbe">Sevres-Lecourbe</option>
			<option value="trocadero">Trocadero</option>
			<option value="charles+de+gaulle+etoile">Charles de Gaulle Etoile</option>
			<option value="nation">Nation</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Charles de Gaule Etoile</option>
				<option value="R">Nation</option></form></select></br><form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
    
			</div>
		</div>

{% endblock %}
