{% extends "layout/default.html" %}
{% block body %}
	<h3>Si vous avez besoin d'aide rendez vous sur <a href="http://onyxlabs.fr">Onyxlabs</a></h3>
<h3>Ou sur le <a href="http://onyxlabs.fr/forum">Forum</a> !</h3>
{% endblock %}
