{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 3</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="anatole+france">Anatole France</option>
			<option value="arts+et+metiers">Arts et Metiers</option>
			<option value="bourse">Bourse</option>
			<option value="europe">Europe</option>
			<option value="gallieni">Gallieni</option>
			<option value="gambetta">Gambetta</option>
			<option value="havre+caumartin">Havre-Caumartin</option>
			<option value="louise+michel">Louise Michel</option>
			<option value="malesherbes">Malesherbes</option>
			<option value="opera">Opera</option>
			<option value="parmentier">Parmentier</option>
			<option value="pereire">Pereire</option>
			<option value="pont+de+levallois+becon">Pont de Levallois Becon</option>
			<option value="porte+de+bagnolet">Porte de Bagnolet</option>
			<option value="pere+lachaise">Pere Lachaise</option>
			<option value="quatre+septembre">Quatre-Septembre</option>
			<option value="rue+saint+maur">Rue Saint-Maur</option>
			<option value="reaumur+sebastopol">Reaumur-Sebastopol</option>
			<option value="republique">Republique</option>
			<option value="saint+lazare">Saint-Lazare</option>
			<option value="sentier">Sentier</option>
			<option value="temple">Temple</option>
			<option value="villiers">Villiers</option>
			<option value="wagram">Wagram</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Pont de Levallois bécon</option>
				<option value="R">Gallieni</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>


{% endblock %}

