{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 4</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="alesia">Alesia</option>
			<option value="barbes+rochechouart">Barbes Rochechouart</option>
			<option value="chateau+rouge">Chateau Rouge</option>
			<option value="chateau+d+eau">Chateau d&#039;Eau</option>
			<option value="cite">Cite</option>
			<option value="denfert+rochereau">Denfert-Rochereau</option>
			<option value="etienne+marcel">Etienne Marcel</option>
			<option value="gare+de+l+est">Gare de l&#039;Est</option>
			<option value="gare+du+nord">Gare du Nord</option>
			<option value="les+halles">Les Halles</option>
			<option value="mairie+de+montrouge">Mairie de Montrouge</option>
			<option value="marcadet+poissonniers">Marcadet Poissonniers</option>
			<option value="montparnasse+bienvenue">Montparnasse Bienvenüe</option>
			<option value="mouton+duvernet">Mouton-Duvernet</option>
			<option value="odeon">Odeon</option>
			<option value="porte+d+orleans">Porte d&#039;Orleans</option>
			<option value="porte+de+clignancourt">Porte de Clignancourt</option>
			<option value="raspail">Raspail</option>
			<option value="reaumur+sebastopol">Reaumur-Sebastopol</option>
			<option value="saint+germain+des+pres">Saint-Germain-des-Pres</option>
			<option value="saint+michel">Saint-Michel</option>
			<option value="saint+placide">Saint-Placide</option>
			<option value="saint+sulpice">Saint-Sulpice</option>
			<option value="simplon">Simplon</option>
			<option value="strasbourg+saint+denis">Strasbourg-Saint-Denis</option>
			<option value="vavin">Vavin</option>
						<option value="chatelet">Chatelet</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Mairie de Montrouge</option>
				<option value="R">Porte de Clignancourt</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>


{% endblock %}

