{% extends 'layout/default.html' %}
{% block body %} 
  <div class="card-panel blue-grey lighten-4">
 


		<div class="panel panel-info">
			<div class="panel-heading">Metro 1</div>
			<div class="panel-body"> 
				<form method="post" action="">
   			 <div class="browser-default col s12">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> 

     		 <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
			<option value="argentine">Argentine</option>
			<option value="bastille">Bastille</option>
			<option value="berault">Berault</option>
			<option value="champs+elysees+clemenceau">Champs-Elysees Clemenceau</option>
			<option value="charles+de+gaulle+etoile">Charles de Gaulle Etoile</option>
			<option value="chateau+de+vincennes">Chateau de Vincennes</option>
			<option value="chatelet">Chatelet</option>
			<option value="concorde">Concorde</option>
			<option value="esplanade+de+la+defense">Esplanade de La Defense</option>
			<option value="franklin+d+roosevelt">Franklin D. Roosevelt</option>
			<option value="gare+de+lyon">Gare de Lyon</option>
			<option value="george+v">George V</option>
			<option value="hotel+de+ville">Hôtel de Ville</option>
			<option value="la+defense">La Defense</option>
			<option value="les+sablons">Les Sablons</option>
			<option value="louvre+rivoli">Louvre - Rivoli</option>
			<option value="nation">Nation</option>
			<option value="palais+royal+musee+du+louvre">Palais Royal Musee du Louvre</option>
			<option value="pont+de+neuilly">Pont de Neuilly</option>
			<option value="porte+maillot">Porte Maillot</option>
			<option value="porte+de+vincennes">Porte de Vincennes</option>
			<option value="reuilly+diderot">Reuilly-Diderot</option>
			<option value="saint+mande">Saint-Mande</option>
			<option value="saint+paul">Saint-Paul</option>
			<option value="tuileries">Tuileries</option>
			</select>
			</div>
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">La Défense</option>
				<option value="R">Chateau de Vincennes</option></form></select></br>
	</br></br>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>
		</div>
		</div>
{% endblock%}



