{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 8</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="balard">Balard</option>
			<option value="bonne+nouvelle">Bonne Nouvelle</option>
			<option value="boucicaut">Boucicaut</option>
			<option value="charenton+ecoles">Charenton-Ecoles</option>
			<option value="chemin+vert">Chemin Vert</option>
			<option value="commerce">Commerce</option>
			<option value="creteil+l+echat">Creteil-L&#039;Echat</option>
			<option value="creteil+prefecture">Creteil-Prefecture</option>
			<option value="creteil+universite">Creteil-Universite</option>
			<option value="daumesnil">Daumesnil</option>
			<option value="ecole+militaire">Ecole Militaire</option>
			<option value="ecole+veterinaire+de+maisons+alfort">Ecole Veterinaire de Maisons-Alfort</option>
			<option value="faidherbe+chaligny">Faidherbe-Chaligny</option>
			<option value="filles+du+calvaire">Filles du Calvaire</option>
			<option value="felix+faure">Felix Faure</option>
			<option value="grands+boulevards">Grands Boulevards</option>
			<option value="invalides">Invalides</option>
			<option value="la+motte+picquet+grenelle">La Motte-Picquet Grenelle</option>
			<option value="la+tour+maubourg">La Tour-Maubourg</option>
			<option value="ledru+rollin">Ledru-Rollin</option>
			<option value="liberte">Liberte</option>
			<option value="lourmel">Lourmel</option>
			<option value="madeleine">Madeleine</option>
			<option value="maisons+alfort+les+juilliottes">Maisons-Alfort Les Juilliottes</option>
			<option value="maisons+alfort+stade">Maisons-Alfort Stade</option>
			<option value="michel+bizot">Michel Bizot</option>
			<option value="montgallet">Montgallet</option>
			<option value="opera">Opera</option>
			<option value="pointe+du+lac">Pointe du Lac</option>
			<option value="porte+doree">Porte Doree</option>
			<option value="porte+de+charenton">Porte de Charenton</option>
			<option value="richelieu+drouot">Richelieu-Drouot</option>
			<option value="republique">Republique</option>
			<option value="saint+sebastien+froissart">Saint-Sebastien Froissart</option>
			<option value="strasbourg+saint+denis">Strasbourg-Saint-Denis</option>
			<option value="bastille">Bastille</option>
			<option value="concorde">Concorde</option>
			<option value="reuilly+diderot">Reuilly-Diderot</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Pointe du lac</option>
				<option value="R">Balard</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn btn-primary" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>


{% endblock %}