#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os

MUSIC_REPO = os.path.dirname(os.path.dirname(os.path.dirname(__file__))) + '/static/music/'
RING_REPO = os.path.dirname(os.path.dirname(os.path.dirname(__file__))) + '/static/ringstone/'


