{% extends "layout/default.html" %}
{% block body %}

<iframe style="border:0px #FFFFFF none;" frameborder="1" width="100%" height="900px" src="https://www.viamichelin.fr/web/Itineraires" frameborder="0"></iframe>
{% endblock %}