{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 13</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="asnieres+gennevilliers les courtilles">Asnieres-Gennevilliers - Les Courtilles</option>
			<option value="basilique+de+saint+denis">Basilique de Saint-Denis</option>
			<option value="brochant">Brochant</option>
			<option value="carrefour+pleyel">Carrefour Pleyel</option>
			<option value="chatillon+montrouge">Chatillon-Montrouge</option>
			<option value="champs+elysees+clemenceau">Champs-Elysees Clemenceau</option>
			<option value="duroc">Duroc</option>
			<option value="gabriel+peri">Gabriel Peri</option>
			<option value="garibaldi">Garibaldi</option>
			<option value="gaite">Gaîte</option>
			<option value="guy+moquet">Guy Môquet</option>
			<option value="invalides">Invalides</option>
			<option value="la+fourche">La Fourche</option>
			<option value="les+agnettes">Les Agnettes</option>
			<option value="liege">Liege</option>
			<option value="mairie+de+clichy">Mairie de Clichy</option>
			<option value="mairie+de+saint+ouen">Mairie de Saint-Ouen</option>
			<option value="malakoff+plateau+de+vanves">Malakoff Plateau de Vanves</option>
			<option value="malakoff+rue+etienne+dolet">Malakoff Rue Etienne Dolet</option>
			<option value="miromesnil">Miromesnil</option>
			<option value="montparnasse+bienvenue">Montparnasse Bienvenüe</option>
			<option value="pernety">Pernety</option>
			<option value="place+de+clichy">Place de Clichy</option>
			<option value="plaisance">Plaisance</option>
			<option value="porte+de+clichy">Porte de Clichy</option>
			<option value="porte+de+saint+ouen">Porte de Saint-Ouen</option>
			<option value="porte+de+vanves">Porte de Vanves</option>
			<option value="saint+denis+porte+de+paris">Saint-Denis-Porte de Paris</option>
			<option value="saint+denis+universite">Saint-Denis-Universite</option>
			<option value="saint+francois+xavier">Saint-Francois-Xavier</option>
			<option value="varenne">Varenne</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Asnières-Gennevilliers Les Courtilles - Saint-Denis-Université</option>
				<option value="R">Châtillon-Montrouge</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>



{% endblock %}
