{% extends "layout/default.html" %}
{% block body %}
		
  <div class="card-panel grey lighten-3">
		        <h2>Mes comptes</h2>		 
		        <h4>{{ error }}</h4>
			<table  class="table table-striped">	
				 <tbody id="table_alarmes">
				<tr>
					<th>Pseudo</th>
					<th>Email</th>
					<th>Id</th>
					<th>Supprimer</th>
				</tr>
				<tr>
		
					<td>{% for tab in username %}
							{{ tab }}</br>
						{% endfor %}
					</td>
					<td>{% for tab in email %}
							{{ tab }}</br>
						{% endfor %}
					</td>
					<td>{% for tab in id %}
							{{ tab }}</br>
						{% endfor %}
					</td>	
					<td>
					{% for tab in id %}
					<a href="{{ url_for('delete_account' , id_delete=tab) }}"><i class="fa fa-times" aria-hidden="true"></i></a></br>
					{% endfor %}
					</td>		
				</tr>
			</tbody>
			</table>
		        
		 </div>

		 
{% endblock %}