{% extends "layout/default.html" %}
{% block body %} 
<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">RER A</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horRERStations" class="stationField">
     		 <label for="RERServiceStationForm_station">Nom de la station : </label> <select name="rerstation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
			<option value="acheres+ville">Acheres Ville</option>
			<option value="Acheres-Grand-Cormier">Acheres-Grand-Cormier</option>
			<option value="Auber" selected="selected">Auber</option>
			<option value="Boissy Saint Leger">Boissy Saint Leger</option>
			<option value="Bry Sur Marne">Bry Sur Marne</option>
			<option value="Bussy St-Georges">Bussy St-Georges</option>
			<option value="Cergy-Le Haut">Cergy-Le Haut</option>
			<option value="Cergy-Prefecture">Cergy-Prefecture</option>
			<option value="Cergy-St-Christophe">Cergy-St-Christophe</option>
			<option value="Champigny">Champigny</option>
			<option value="Charles de Gaulle-Etoile">Charles de Gaulle-Etoile</option>
			<option value="Chatelet-Les-Halles">Chatelet-Les-Halles</option>
			<option value="Chatou-Croissy">Chatou-Croissy</option>
			<option value="Conflans-Fin d&#039;Oise">Conflans-Fin d&#039;Oise</option>
			<option value="Fontenay Sous Bois">Fontenay Sous Bois</option>
			<option value="Gare de Lyon">Gare de Lyon</option>
			<option value="Grande Arche la Defense">Grande Arche la Defense</option>
			<option value="Houilles">Houilles</option>
			<option value="Joinville le Pont">Joinville le Pont</option>
			<option value="La Varenne-Chennevieres">La Varenne-Chennevieres</option>
			<option value="Le Parc de Saint Maur">Le Parc de Saint Maur</option>
			<option value="Le Vesinet Centre">Le Vesinet Centre</option>
			<option value="Le Vesinet le Pecq">Le Vesinet le Pecq</option>
			<option value="Lognes">Lognes</option>
			<option value="Maisons-Laffitte">Maisons-Laffitte</option>
			<option value="Marne la Vallee-Chessy">Marne la Vallee-Chessy</option>
			<option value="Nanterre Prefecture">Nanterre Prefecture</option>
			<option value="Nanterre Universite">Nanterre Universite</option>
			<option value="Nanterre Ville">Nanterre Ville</option>
			<option value="Nation">Nation</option>
			<option value="Neuilly-Plaisance">Neuilly-Plaisance</option>
			<option value="Neuville Universite">Neuville Universite</option>
			<option value="Nogent Sur Marne">Nogent Sur Marne</option>
			<option value="Noisiel">Noisiel</option>
			<option value="Noisy le Grand-Mont d&#039;Est">Noisy le Grand-Mont d&#039;Est</option>
			<option value="Noisy-Champs">Noisy-Champs</option>
			<option value="Poissy">Poissy</option>
			<option value="Rueil Malmaison">Rueil Malmaison</option>
			<option value="Saint Maur-Creteil">Saint Maur-Creteil</option>
			<option value="Sartrouville">Sartrouville</option>
			<option value="St Germain en Laye">St Germain en Laye</option>
			<option value="Sucy-Bonneuil">Sucy-Bonneuil</option>
			<option value="Torcy">Torcy</option>
			<option value="Val d&#039;Europe-Serris">Val d&#039;Europe-Serris</option>
			<option value="Val de Fontenay">Val de Fontenay</option>
			<option value="Vincennes">Vincennes</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="rer-service-arret-form">
   			 <div id="horRERStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="rerdirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre direction--">--Choisissez votre direction--</option>
				<option value="A">St-Germain-en-Laye. Poissy. Cergy.</option>
				<option value="R">Boissy-St-Léger. Marne-la-Vallée.</option>
			</form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember">Ajouter au favoris
    </label></br></br>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>

{% endblock %}



