{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 12</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="abbesses">Abbesses</option>
			<option value="assemblee+nationale">Assemblee Nationale</option>
			<option value="convention">Convention</option>
			<option value="corentin+celton">Corentin Celton</option>
			<option value="falguiere">Falguiere</option>
			<option value="front+populaire">Front Populaire</option>
			<option value="jules+joffrin">Jules Joffrin</option>
			<option value="lamarck+caulaincourt">Lamarck Caulaincourt</option>
			<option value="madeleine">Madeleine</option>
			<option value="mairie+d+issy">Mairie d&#039;Issy</option>
			<option value="marcadet+poissonniers">Marcadet Poissonniers</option>
			<option value="marx+dormoy">Marx Dormoy</option>
			<option value="montparnasse+bienvenue">Montparnasse Bienvenüe</option>
			<option value="notre+dame+de+lorette">Notre-Dame-de-Lorette</option>
			<option value="notre+dame+des+champs">Notre-Dame-des-Champs</option>
			<option value="pasteur">Pasteur</option>
			<option value="pigalle">Pigalle</option>
			<option value="porte+de+versailles">Porte de Versailles</option>
			<option value="porte+de+la+chapelle">Porte de la Chapelle</option>
			<option value="rennes">Rennes</option>
			<option value="rue+du+bac">Rue du Bac</option>
			<option value="saint+georges">Saint-Georges</option>
			<option value="saint+lazare">Saint-Lazare</option>
			<option value="solferino">Solferino</option>
			<option value="sevres+babylone">Sevres-Babylone</option>
			<option value="trinite+d+estienne+d+orves">Trinite d&#039;Estienne d&#039;Orves</option>
			<option value="vaugirard">Vaugirard</option>
			<option value="volontaires">Volontaires</option>
			<option value="concorde">Concorde</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Front Populaire</option>
				<option value="R">Mairie d'Issy</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn btn-primary" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>


{% endblock %}

