{% extends "layout/default.html" %}
{% block body %} 
	<br>
  <div class="card-panel blue-grey lighten-4">
		<div class="panel panel-info">
			<div class="panel-heading">Metro 11</div>
			<div class="panel-body"> 
				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="arts+et+metiers">Arts et Metiers</option>
			<option value="belleville">Belleville</option>
			<option value="goncourt">Goncourt</option>
			<option value="jourdain">Jourdain</option>
			<option value="mairie+des+lilas">Mairie des Lilas</option>
			<option value="pyrenees">Pyrenees</option>
			<option value="rambuteau">Rambuteau</option>
			<option value="republique">Republique</option>
			<option value="telegraphe">Telegraphe</option>
			<option value="chatelet">Chatelet</option>
			<option value="hotel+de+ville">Hôtel de Ville</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Châtelet</option>
				<option value="R">Mairis des Lilas</option></form></select></br>
				<form method="post" action="">
    <label class="checkbox">
    	<input type="checkbox" name="remember" value="1">Ajouter au favoris
    </label><p></br></br></p>
    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>
    </form>
			</div>
		</div>


{% endblock %}

