{% extends "layout/default.html" %}
{% block body %}

  <div class="card-panel blue-grey lighten-4">
	<a href="{{ url_for('metro') }}" class="waves-effect waves-light btn {{ buttonColor }}">Metro</a>
	<a  href="{{ url_for('rer') }}" class="waves-effect waves-light btn {{ buttonColor }}">RER</a>
</div>

{% endblock %}