{% extends "layout/default.html" %}
{% block body %}
		
  <div class="card-panel grey lighten-3">
		        <h2>Mon compte</h2>		 

    <span class="btn-floating btn-large {{ buttonColor }}"></span><br>
    <h5>Pseudo</h5> {{ currentUser }}
    <h5>Email</h5>{{ currentEmail }}
		        <h3>Changez mes informations :</h3> <br>

		          <form class="form" method=post action="">
	  <div class="container">
	  <label for="username" >Nouveau pseudo</label>
	  <input type="text" id="username" name="username" value="{{ request.form.username }}">

	  <label for="password" >Nouveau mot de passe</label>
      <input type="password" id="password"  name="password" value="{{ request.form.password }}">

      <label for="email" >Nouvel Email</label>
      <input type="email" id="email" name="email" value="{{ request.form.email }}">

       <label for="lastpassword" >Ancien mot de passe</label>     
      <input type="password" id="lastpassword"  name="lastpassword" value="{{ request.form.lastpassword }}" required>


      </div>

      <br>

		       
 
      <input name="color" type="radio" id="red darken-1" value="red darken-1"/>
      <label for="red darken-1" ><a class="btn red darken-1"></a></label>

      <input name="color" type="radio" id="pink" value="pink" />
      <label for="pink" ><a class="btn pink"></a></label>

      <input name="color" type="radio" id="purple darken-1" value="purple darken-1"/>
      <label for="purple darken-1" ><a class="btn purple darken-1"></a></label>

      <input name="color" type="radio" id="deep-purple darken-1" value="deep-purple darken-1"/>
      <label for="deep-purple darken-1" ><a class="btn deep-purple darken-1"></a></label>
<br><br>
      <input name="color" type="radio" id="indigo darken-1" value="indigo darken-1"/>
      <label for="indigo darken-1" ><a class="btn indigo darken-1"></a></label>

      <input name="color" type="radio" id="blue darken-1" value="blue darken-1"/>
      <label for="blue darken-1" ><a class="btn blue darken-1"></a></label>

      <input name="color" type="radio" id="light-blue darken-1" value="light-blue darken-1"/>
      <label for="light-blue darken-1" ><a class="btn light-blue darken-1"></a></label>

      <input name="color" type="radio" id="cyan darken-1" value="cyan darken-1"/>
      <label for="cyan darken-1" ><a class="btn cyan darken-1"></a></label>
<br><br>
      <input name="color" type="radio" id="teal darken-1" value="teal darken-1"/>
      <label for="teal darken-1" ><a class="btn teal darken-1"></a></label>

      <input name="color" type="radio" id="green darken-1" value="green darken-1"/>
      <label for="green darken-1" ><a class="btn green darken-1"></a></label>

      <input name="color" type="radio" id="light-green darken-1" value="light-green darken-1"/>
      <label for="light-green darken-1" ><a class="btn light-green darken-1"></a></label>

      <input name="color" type="radio" id="lime darken-1 darken-1" value="lime darken-1 darken-1"/>
      <label for="lime darken-1 darken-1" ><a class="btn lime darken-1 darken-1"></a></label>


<br><br>
      <input name="color" type="radio" id="yellow darken-1" value="yellow darken-1"/>
      <label for="yellow darken-1" ><a class="btn yellow darken-1"></a></label>

      <input name="color" type="radio" id="amber darken-1" value="amber darken-1"/>
      <label for="amber darken-1" ><a class="btn amber darken-1"></a></label>

      <input name="color" type="radio" id="orange darken-1" value="orange darken-1"/>
      <label for="orange darken-1" ><a class="btn orange darken-1"></a></label>

      <input name="color" type="radio" id="deep-orange darken-1" value="deep-orange darken-1"/>
      <label for="deep-orange darken-1" ><a class="btn deep-orange darken-1"></a></label>
<br><br>
      <input name="color" type="radio" id="brown darken-1 darken-1" value="brown darken-1 darken-1"/>
      <label for="brown darken-1 darken-1" ><a class="btn brown darken-1"></a></label>

      <input name="color" type="radio" id="default" value="None"/>
      <label for="default" ><a class="btn"></a></label>



      <br>
      <br>

      <button class="btn {{ buttonColor }}">Enregistrer les modifications</button>
    </form>

  

		 
{% endblock %}