

<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/2.1.4/jquery.min.js"></script>
<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.10.2/moment.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/fullcalendar/2.7.1/fullcalendar.min.js"></script>
<script src="http://fullcalendar.io/js/fullcalendar-2.8.0/lang-all.js"></script>
<script src="http://fullcalendar.io/js/fullcalendar-2.8.0/gcal.js"></script>
<script src="{{ url_for('static', filename='js/mustache.js') }}"></script>
<script src="{{ url_for('static', filename='js/pnotify.js') }}"></script>    
<script type="text/javascript" src="includes/themeswitcher/jquery.themeswitcher.min.js"></script>
<script src="{{ url_for('static', filename='js/hours.js') }}"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/materialize/0.97.6/js/materialize.min.js"></script>
<script src="{{ url_for('static', filename='js/wickedpicker.min.js') }}"></script>
<script src="https://sciactive.github.io/pnotify/src/pnotify.buttons.js"></script>
<script type="text/javascript">$('.timepicker').wickedpicker({twentyFour: true});</script>
<script type="text/javascript" src="{{ url_for('static', filename='js/wikipedia.js') }}"></script>
<script type="text/javascript">$('.button-collapse').sideNav();</script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery.gridster/0.5.6/jquery.gridster.min.js" type="text/javascript"></script>