{% macro get_css(nom_fichiers , extension='css') -%}
    {% for fichier in nom_fichiers %}
        <link href="{{ url_for('static', filename='css/' + fichier + '.' + extension) }}" rel="stylesheet" type="text/css" />
    {% endfor %}
{%- endmacro %}

<link rel="shortcut icon" type="image/x-icon" href="{{ url_for('static', filename='images/favicon.ico') }}" />
{{ get_css(['materialize' , 'login', 'notif' , 'notif-theme.min']) }}
<link href="http://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
<link rel="stylesheet" type="text/css" href="http://netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css" rel="stylesheet">
<link href="http://cdnjs.cloudflare.com/ajax/libs/animate.css/3.4.0/animate.min.css" rel="stylesheet" type="text/css" />
<link href="https://sciactive.github.io/pnotify/src/pnotify.brighttheme.css" rel="stylesheet" type="text/css" />
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/pnotify/3.0.0/pnotify.css">
<link rel="stylesheet" type="text/css" href="http://netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css" rel="stylesheet">

<link href="https://sciactive.github.io/pnotify/src/pnotify.buttons.css" rel="stylesheet">